@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: chooseip.php,v 1.22 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: chooseip.php,v 1.23 2004/02/21 19:38:16 lukasz Exp $
  */
 
-$p = $_GET[p];
+$p = $_GET['p'];
 
 if(!isset($p))
 	$js = "var targetfield = window.opener.targetfield;";
@@ -33,27 +33,27 @@ if($p == "main")
 
 $networks = $LMS->GetNetworks();
 
-if (isset($_POST[netid]))
-    $netid= $_POST[netid];
+if (isset($_POST['netid']))
+    $netid= $_POST['netid'];
 
-elseif (isset($_SESSION[netid]))
-    $netid = $_SESSION[netid];
+elseif (isset($_SESSION['netid']))
+    $netid = $_SESSION['netid'];
     
 else
-    $netid = $networks[0][id];
+    $netid = $networks[0]['id'];
 
-$_SESSION[netid] = $netid;
+$_SESSION['netid'] = $netid;
 
 if($p == "main")
 	$network = $LMS->GetNetwork($netid);
 
-$layout[pagetitle] = "Wybierz adres IP";
+$layout['pagetitle'] = "Wybierz adres IP";
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("part",$p);
-$SMARTY->assign("js",$js);
-$SMARTY->assign("networks",$networks);
-$SMARTY->assign("network",$network);
-$SMARTY->display("chooseip.html");
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('part',$p);
+$SMARTY->assign('js',$js);
+$SMARTY->assign('networks',$networks);
+$SMARTY->assign('network',$network);
+$SMARTY->display('chooseip.html');
 
 ?>
