@@ -1,7 +1,7 @@
 <?
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: confgen.php,v 1.5 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: confgen.php,v 1.6 2004/02/21 19:38:16 lukasz Exp $
  */
 
 // zacznijmy od budowania listy hostw:
 
-if($_GET[tpl] == '')
+if($_GET['tpl'] == '')
 {
-	$layout[pagetitle] = 'Pliki konfiguracyjne';
+	$layout['pagetitle'] = 'Pliki konfiguracyjne';
 	$templateslist = $LMS->GetTemplatesList();
 	$SMARTY->assign('templateslist',$templateslist);
 	$SMARTY->assign('layout',$layout);
@@ -43,7 +43,7 @@ else
 	$SMARTY->template_dir = $LMS->CONFIG['directories']['config_templates_dir'];
 	$SMARTY->left_delimiter = '<?';
 	$SMARTY->right_delimiter = '?>';
-	$SMARTY->display($_GET[tpl].'.tpl');
+	$SMARTY->display($_GET['tpl'].'.tpl');
 }
 
 ?>
