@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: copyrights.php,v 1.18 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: copyrights.php,v 1.19 2004/02/21 19:38:16 lukasz Exp $
  */
 
-$layout[pagetitle]="Informacje o prawach autorskich";
+$layout['pagetitle'] = "Informacje o prawach autorskich";
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->display("header.html");
-$SMARTY->display("copyrights.html");
-$SMARTY->display("footer.html");
+$SMARTY->assign('layout',$layout);
+$SMARTY->display('header.html');
+$SMARTY->display('copyrights.html');
+$SMARTY->display('footer.html');
 
 ?>
\ No newline at end of file
