@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,24 +21,24 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netlist.php,v 1.23 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: netlist.php,v 1.24 2004/02/21 19:38:17 lukasz Exp $
  */
 
-$layout[pagetitle]="Sieci IP";
+$layout['pagetitle'] = "Sieci IP";
 
 $netlist = $LMS->GetNetworkList();
 
-$listdata[size] = $netlist[size];
-$listdata[assigned] = $netlist[assigned];
+$listdata['size'] = $netlist['size'];
+$listdata['assigned'] = $netlist['assigned'];
 
-unset($netlist[assigned], $netlist[size], $netlist[total]);
+unset($netlist['assigned'], $netlist['size'], $netlist['total']);
 
-$listdata[total] = sizeof($netlist);
+$listdata['total'] = sizeof($netlist);
 
-$SMARTY->assign("listdata",$listdata);
-$SMARTY->assign("netadd",$netadd);
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("netlist",$netlist);
-$SMARTY->display("netlist.html");
+$SMARTY->assign('listdata',$listdata);
+$SMARTY->assign('netadd',$netadd);
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('netlist',$netlist);
+$SMARTY->display('netlist.html');
 
 ?>
