@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeset.php,v 1.16 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: nodeset.php,v 1.17 2004/02/21 19:38:17 lukasz Exp $
  */
 
 if($LMS->UserExists($_GET['ownerid']))
@@ -43,6 +43,6 @@ if(isset($_GET['netdev']))
 		$backid = $_GET['netdev'];
 	}
 
-header("Location: ?".$_SESSION[backto]."#".$backid);
+header("Location: ?".$_SESSION['backto']."#".$backid);
 
 ?>
