@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentedit.php,v 1.3 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: paymentedit.php,v 1.4 2004/02/21 19:38:17 lukasz Exp $
  */
 
 if(!$LMS->PaymentExists($_GET['id']))
@@ -121,11 +121,11 @@ if(isset($payment))
 		$payment['at'] = sprintf("%02d/%02d",($payment['at']%100),$payment['at']/100+1);
 }
 	
-$layout['pagetitle']="Edycja opaty staej: ".$payment['name'];	
+$layout['pagetitle'] = "Edycja opaty staej: ".$payment['name'];	
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("payment",$payment);
-$SMARTY->assign("error",$error);
-$SMARTY->display("paymentedit.html");
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('payment',$payment);
+$SMARTY->assign('error',$error);
+$SMARTY->display('paymentedit.html');
 
 ?>
