@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: reload.php,v 1.25 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: reload.php,v 1.26 2004/02/21 19:38:17 lukasz Exp $
  */
 
 // Agggrrr. Nie zwracajcie uwagi na styl pisania *TEGO* kawaka kodu :)
@@ -29,7 +29,7 @@
 
 $layout[$pagetitle]="Przeadowanie konfiguracji";
 
-$SMARTY->display("header.html");
+$SMARTY->display('header.html');
 
 ?><H1>Przeadowanie konfiguracji</H1><?php
 
@@ -94,6 +94,6 @@ switch($_RELOAD_TYPE)
 
 }
 
-$SMARTY->display("footer.html");
+$SMARTY->display('footer.html');
 
 ?>
