@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: setlang.php,v 1.7 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: setlang.php,v 1.8 2004/02/21 19:38:17 lukasz Exp $
  */
 
-$LMS->SetAdminLang($SESSION->id,$_GET[lang]);
+$LMS->SetAdminLang($SESSION->id,$_GET['lang']);
 
 header("Location: ?m=welcome");
 
