@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,11 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffdelete.php,v 1.18 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: tariffdelete.php,v 1.19 2004/02/21 19:38:17 lukasz Exp $
  */
 
-if(!$LMS->GetUsersWithTariff($_GET[id])&&$_GET[is_sure]="1")
-	$LMS->TariffDelete($_GET[id]);	
+if(!$LMS->GetUsersWithTariff($_GET['id'])&&$_GET['is_sure']="1")
+	$LMS->TariffDelete($_GET['id']);	
 
 header("Location: ?m=tarifflist");
 die;
