@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.1 Maybourne
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,15 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: template.php,v 1.18 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: template.php,v 1.19 2004/02/21 19:38:17 lukasz Exp $
  */
 
-$layout[pagetitle]="Tytu moduu";
-$SMARTY->assign("layout",$layout);
-$SMARTY->display("header.html");
+$layout['pagetitle'] = "Tytu moduu";
+$SMARTY->assign('layout',$layout);
+$SMARTY->display('header.html');
 
 // Tutaj odpowiednie dziaania
 
-$SMARTY->display("footer.html");
+$SMARTY->display('footer.html');
 
 ?>
\ No newline at end of file
